@@ -13,11 +13,14 @@ class FieldDefinition(OrderedDict):
         return ', '.join([ f'{k} {v}' for k, v in zip(self.keys(), self.values())])
     
     def __add__(self, other):
-        print(other)
+        # print(other)
         for k, v in  zip(other.keys(), other.values()):
             self[k] = v
         return self
 
+    def __eq__(self, other):
+        return str(self) == str(other)
+
 class FieldList(list):
     def __init__(self,):
         super(FieldList, self).__init__()
